#[repr(u32)]pub enum PixelFormat {
Show 24 variants
Invalid = 0,
R8G8B8A8 = 1,
R8G8B8X8 = 119,
B8G8R8A8 = 101,
B8G8R8X8 = 120,
I420 = 102,
M420 = 103,
Nv12 = 104,
Yuy2 = 105,
Mjpeg = 106,
Yv12 = 107,
B8G8R8 = 108,
R5G6B5 = 109,
R3G3B2 = 110,
R2G2B2X2 = 111,
L8 = 112,
R8 = 113,
R8G8 = 114,
A2R10G10B10 = 115,
A2B10G10R10 = 116,
P010 = 117,
R8G8B8 = 118,
DoNotCare = 4_294_967_294,
UnknownOrdinal_(u32),
}Expand description
Expresses the manner in which video pixels are encoded.
The ordering of the channels in the format name reflects the actual layout of the channel.
Each of these values is opinionated re. the color spaces that should be contained within (in contrast with Vulkan).
Variants
Invalid = 0
R8G8B8A8 = 1
R8G8B8X8 = 119
B8G8R8A8 = 101
B8G8R8X8 = 120
I420 = 102
M420 = 103
Nv12 = 104
Yuy2 = 105
Mjpeg = 106
Yv12 = 107
B8G8R8 = 108
R5G6B5 = 109
R3G3B2 = 110
R2G2B2X2 = 111
L8 = 112
R8 = 113
R8G8 = 114
A2R10G10B10 = 115
A2B10G10R10 = 116
P010 = 117
R8G8B8 = 118
DoNotCare = 4_294_967_294
UnknownOrdinal_(u32)